RecordCopyWith<Result, T extends Record> class abstract

Implemented types
Implementers

Constructors

RecordCopyWith()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$delta(Map<String, dynamic> delta) → Result
$merge(T value) → Result
$update(T transform(T)) → Result
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited